==> odoo_19.0.20260121.zip: odoo-19.0.post20260121/odoo/addons/test_mail_full/controllers/portal.py <==
from odoo import http
from odoo.http import request


class PortalTest(http.Controller):
    """Implements some test portal routes (ex.: for viewing a record)."""

    @http.route('/my/test_portal/<int:res_id>', type='http', auth='public', methods=['GET'])
    def test_portal_record_view(self, res_id, access_token=None, **kwargs):
        return request.make_response(f'Record view of test_portal {res_id} ({access_token}, {kwargs})')

    @http.route("/my/test_portal_records/<int:res_id>", type="http", auth="public", website=True)
    def test_portal_record_page(self, res_id, **kwargs):
        record = request.env["mail.test.portal"]._get_thread_with_access(res_id, **kwargs)
        values = {
            "object": record,
            "token": kwargs.get("token"),
            "hash": kwargs.get("hash", None),
            "pid": kwargs.get("pid", None),
        }
        return request.render("test_mail_full.test_portal_template", values)

    @http.route("/my/test_portal_rating_records/<int:res_id>", type="http", auth="public", website=True)
    def test_portal_rating_record_page(self, res_id, **kwargs):
        access_params = {
            "hash": kwargs.get("hash"),
            "pid": kwargs.get("pid"),
            "token": kwargs.get("token"),
        }
        record = request.env["mail.test.rating"]._get_thread_with_access(res_id, **access_params)
        return request.render(
            "test_mail_full.test_portal_template",
            {
                **access_params,
                "object": record,
                "display_rating": kwargs.get("display_rating"),
            },
        )

    @http.route('/test_portal/public_type/<int:res_id>', type='http', auth='public', methods=['GET'])
    def test_public_record_view(self, res_id):
        return request.make_response(f'Testing public controller for {res_id}')

==> odoo_19.2a1.20260129.zip: odoo-19.2a1.post20260129/odoo/addons/test_mail_full/controllers/portal.py <==
from odoo import http
from odoo.http import request


class PortalTest(http.Controller):
    """Implements some test portal routes (ex.: for viewing a record)."""

    @http.route('/my/test_portal/<int:res_id>', type='http', auth='public', methods=['GET'])
    def test_portal_record_view(self, res_id, access_token=None, **kwargs):
        return request.make_response(f'Record view of test_portal {res_id} ({access_token}, {kwargs})')

    @http.route("/my/test_portal_records/<int:res_id>", type="http", auth="public", website=True)
    def test_portal_record_page(self, res_id, **kwargs):
        record = request.env["mail.test.portal"]._get_thread_with_access(res_id, **kwargs)
        values = {
            "object": record,
            "token": kwargs.get("token"),
            "hash": kwargs.get("hash", None),
            "pid": kwargs.get("pid", None),
        }
        return request.render("test_mail_full.test_portal_template", values)

    @http.route("/my/test_portal_rating_records/<int:res_id>", type="http", auth="public", website=True)
    def test_portal_rating_record_page(self, res_id, **kwargs):
        access_params = {
            "hash": kwargs.get("hash"),
            "pid": kwargs.get("pid"),
            "token": kwargs.get("token"),
        }
        record = request.env["mail.test.rating"]._get_thread_with_access(res_id, **access_params)
        return request.render(
            "test_mail_full.test_portal_template",
            {
                **access_params,
                "object": record,
                "display_rating": kwargs.get("display_rating"),
            },
        )

    @http.route('/test_portal/public_type/<int:res_id>', type='http', auth='public', methods=['GET'])
    def test_public_record_view(self, res_id):
        return request.make_response(f'Testing public controller for {res_id}')

    @http.route("/my/test_portal_no_partner/<int:res_id>", type="http", auth="public", website=True)
    def test_no_partner_portal_record_page(self, res_id, **kwargs):
        allowed_params = request.env["mail.test.portal.no.partner"]._get_allowed_access_params()
        access_kwargs = {k: v for k, v in kwargs.items() if k in allowed_params}
        record = request.env["mail.test.portal.no.partner"]._get_thread_with_access(res_id, **access_kwargs)
        return request.render("test_mail_full.test_portal_template", {"object": record})
